California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 023 - SUSPENDS AIR POLLUTION CONTROL LAWS REQUIRING MAJOR POLLUTERS TO REPORT AND REDUCE GREENHOUSE GAS EMISSIONS THAT CAUSE GLOBAL WARMING UNTIL UNEMPLOYMENT DROPS BELOW SPECIFIED LEVEL View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1326972 | CREDO VICTORY FUND AGAINST PROP 23 AND TEXAS OIL COMPANIES | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1332395 | GREEN TECHNOLOGY LEADERSHIP GROUP PAC, NO ON PROP 23 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1333075 | CONSUMERS UNION ACTION FUND, INC. - NO ON 23 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288513 | CALIFORNIANS FOR CLEAN AIR AND CLEAN ENERGY JOBS, NO ON 23, NO ON 26, A PROJECT OF CALIFORNIA LEAGUE OF CONSERVATION VOTERS. | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1333283 | BALLOT INITIATIVE STRATEGY CENTER-CA OPPOSED TO PROP 23 AND PROP 26 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1330171 | CLEAN ENERGY AND GOOD JOBS MOBILIZATION COMMITTEE - NO ON 23 AND 26 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1327926 | COMMUNITIES UNITED AGAINST PROPOSITION 23 AND 26, SPONOSRED BY ELLA BAKER CENTER FOR HUMAN RIGHTS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1306041 | NO ON PROP 23 COMMITTEE OF THE NRDC ACTION FUND TO STOP THE DIRTY ENERGY PROPOSITION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1329124 | GREEN TECH ACTION FUND CALIFORNIA COMMITTEE - NO ON 23 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1331668 | COMMITTEE TO DEFEAT PROP 23, SPONSORED BY THE CALIFORNIA STUDENT PUBLIC INTEREST RESEARCH GROUP AND A COALITION OF ENVIRONMENTALISTS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1323890 | YES ON 23, CALIFORNIA JOBS INITIATIVE, A COALITION OF TAXPAYERS, EMPLOYERS, FOOD PRODUCERS, ENERGY, TRANSPORTATION AND FORESTRY COMPANIES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1328106 | CLEAN ECONOMY NETWORK NO ON 23 ACTION FUND, SUPPORTED BY CLEAN TECHNOLOGY COMPANIES, RENEWABLE ENERGY ENTREPRENEURS, AND CONCERNED CITIZENS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1331815 | CALIFORNIA ALLIANCE ACTION FUND: A COMMITTEE SPONSORED BY SOCIAL JUSTICE ORGANIZATIONS FOR PROPOSITIONS 24, 25 AND AGAINST PROPOSITIONS 23, 26 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1328168 | COMMITTEE FOR A CLEAN ENERGY FUTURE NO ON PROP 23 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1324059 | CALIFORNIANS FOR CLEAN ENERGY AND JOBS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1332741 | SILICON VALLEY LEADERSHIP GROUP'S SAVE CALIFORNIA JOBS NOW - NO ON PROPOSITION 23 AND NO ON PROPOSITION 24, AND YES ON SANTA CLARA COUNY MEASURE B | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1329332 | COMMITTEE TO DEFEAT PROP 23, SPONSORED BY ENVIRONMENT CALIFORNIA | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1332177 | ENVIRONMENTAL DEFENSE ACTION FUND SAY NO TO PROP 23 AND 26 COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1327853 | SIERRA CLUB CALIFORNIA NO ON PROP 23 COMMITTEE: CLEAN ENERGY ADVOCATES MAJOR FUNDING BY SIERRA CLUB AND SIERRA CLUB FOUNDATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1307787 | HERRERA, CALIFORNIANS FOR PROGRESS, NO ON 23, A COALITION OF CONSUMERS AND DENNIS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1327753 | MOVEON.ORG PAC (NO ON 23) | OPPOSE